@@ -2,20 +2,11 @@ import os
 import shlex
 import sys
 import argparse
-from jupyter_console.app import ZMQTerminalIPythonApp
 from icortex.services import get_available_services
 from icortex.defaults import DEFAULT_ICORTEX_CONFIG_PATH
-from icortex.install import is_kernel_installed, main as install_kernel
+from icortex.kernel.install import is_kernel_installed, main as install_kernel
 from icortex.config import ICortexConfig
 
-# Jupyter devs did not make this easy
-# TODO: Make less hacky
-class ZMQTerminalICortexApp(ZMQTerminalIPythonApp):
-    def parse_command_line(self, argv=None):
-        argv = ["--kernel", "icortex"]
-        super(ZMQTerminalIPythonApp, self).parse_command_line(argv)
-        self.build_kernel_argv(self.extra_args)
-
 
 def get_parser(prog=None):
     service_names = get_available_services()
@@ -29,7 +20,7 @@ def get_parser(prog=None):
     # Initialize ICortex #
     ######################
 
-    # //init
+    # icortex init
     parser_init = subparsers.add_parser(
         "init",
         help="Initialize ICortex configuration in the current directory",
@@ -51,7 +42,7 @@ def get_parser(prog=None):
     # Shell related commands #
     ##########################
 
-    # //shell
+    # icortex shell
     parser_shell = subparsers.add_parser(
         "shell",
         help="Start ICortex shell",
@@ -62,7 +53,7 @@ def get_parser(prog=None):
     # Help #
     ########
 
-    # //help
+    # icortex help
     parser_help = subparsers.add_parser(
         "help",
         help="Print help",
@@ -73,7 +64,7 @@ def get_parser(prog=None):
     # Service related commands #
     ############################
 
-    # //service
+    # icortex service
     parser_service = subparsers.add_parser(
         "service",
         help="Set and configure code generation services",
@@ -84,7 +75,7 @@ def get_parser(prog=None):
         required=True,
     )
 
-    # //service set <service_name>
+    # icortex service set <service_name>
     parser_service_commands_set = parser_service_commands.add_parser(
         "set",
         help="Set the service to be used for code generation",
@@ -96,21 +87,21 @@ def get_parser(prog=None):
         help="Name of the service to be used for code generation",
     )
 
-    # //service show <service_name>
+    # icortex service show <service_name>
     parser_service_commands_show = parser_service_commands.add_parser(
         "show",
         help="Show current service",
         add_help=False,
     )
 
-    # //service help
+    # icortex service help
     parser_service_commands_help = parser_service_commands.add_parser(
         "help",
-        help="Print help for //service",
+        help="Print help for the current service",
         add_help=False,
     )
 
-    # //service set-var <variable_name> <variable_value>
+    # icortex service set-var <variable_name> <variable_value>
     parser_service_commands_set_var = parser_service_commands.add_parser(
         "set-var",
         help="Set a variable for the current service",
@@ -126,7 +117,7 @@ def get_parser(prog=None):
         help="New value for the variable",
     )
 
-    # //service init <service_name>
+    # icortex service init <service_name>
     # Used to re-spawn the config dialog if some config for the service
     # already exists
     parser_service_commands_init = parser_service_commands.add_parser(
@@ -150,7 +141,6 @@ def get_parser(prog=None):
 
 
 # def set_icortex_service(kernel, config_path=DEFAULT_ICORTEX_CONFIG_PATH):
-
 #     if kernel is not None:
 #         return ICortexConfig(DEFAULT_ICORTEX_CONFIG_PATH).set_service()
 #     return False
@@ -195,6 +185,8 @@ def main(argv=None, prog=None, kernel=None):
         parser.print_help()
     elif args.command == "shell" or args.command is None:
         from icortex.kernel import get_icortex_kernel
+        from icortex.kernel.app import ZMQTerminalICortexApp
+
         kernel = get_icortex_kernel()
         if kernel is None:
             ZMQTerminalICortexApp.launch_instance()
@@ -206,7 +198,7 @@ def main(argv=None, prog=None, kernel=None):
 def eval_cli(prompt: str):
     argv = shlex.split(prompt)
     try:
-        return main(argv=argv, prog="//")
+        return main(argv=argv, prog=r"%icortex")
     except SystemExit:
         return
 
