@@ -35,8 +35,9 @@ class ICortexHistory:
     """Interface to construct a history variable in globals for storing
     notebook context.
     The constructed dict maps to JSON, and the schema is compatible
-    with the Jupyter notebook format:
-    https://nbformat.readthedocs.io/en/latest/format_description.html"""
+    with the
+    `Jupyter notebook format <https://nbformat.readthedocs.io/en/latest/format_description.html>`__:
+    """
 
     def __init__(self, scope: t.Dict[str, t.Any]):
         self.scope = scope
@@ -78,7 +79,11 @@ class ICortexHistory:
 
         ret = {
             "cell_type": "code",
+            # It is actually a prompt, but "code" here refers to the Jupyter cell type
             "metadata": {
+                # Any ICortex specific information needs to be stored here to
+                # adhere to the Jupyter notebook format
+                "source_type": "prompt", # This tells that the input was a prompt
                 "service": service_interaction,
             },
             "source": prompt,
