@@ -22,7 +22,7 @@ class EchoService(ServiceBase):
         self,
         prompt: str,
         context: t.Dict[str, t.Any] = {},
-    ):
+    ) -> t.List[t.Dict[t.Any, t.Any]]:
         argv = shlex.split(prompt)
 
         # Remove the module name flag from the prompt
